# This module has moved to zope.traversing.browser.absoluteurl
# and will go away in Zope 3.5
import zope.deprecation
zope.deprecation.moved(
    'zope.traversing.browser.absoluteurl',
    "Zope 3.5",
    )
